globals
[
  grid-x-inc               ;; the amount of patches in between two roads in the x direction
  grid-y-inc               ;; the amount of patches in between two roads in the y direction
  acceleration             ;; the constant that controls how much a car speeds up or slows down by if
                           ;; it is to accelerate or decelerate
  phase                    ;; keeps track of the phase
  num-cars-stopped         ;; the number of cars that are stopped during a single pass thru the go procedure

  ;; patch agentsets
  intersections            ;; agentset containing the patches that are intersections
  roads                    ;; agentset containing the patches that are roads
  roads-locations

  total-lifetime
  total-killed-cars
  avg-lifetime

  emission-rate            ;; grams of CO2 per kilometer
  emission-rate-idle       ;; grams of CO2 per second
  total-emissions
  total-emissions-idle
]

turtles-own
[
  speed               ;; the speed of the turtle
  actual-speed        ;; speed that is corresponding to km/h in real life
  up-car?             ;; true if the turtle moves downwards and false if it moves to the right
  wait-time           ;; the amount of time since the last time a turtle has moved
  lifetime            ;; how many tics the turtle has until it dies
  distance-traveled   ;; distance traveled by the car
  emissions           ;; emissions generated by the car
  emissions-idle      ;; emissions generated by the car on idle
]

patches-own
[
  intersection?   ;; true if the patch is at the intersection of two roads
  green-light-up? ;; true if the green light is above the intersection.  otherwise, false.
                  ;; false for a non-intersection patches.
  my-row          ;; the row of the intersection counting from the upper left corner of the
                  ;; world.  -1 for non-intersection patches.
  my-column       ;; the column of the intersection counting from the upper left corner of the
                  ;; world.  -1 for non-intersection patches.
  my-phase        ;; the phase for the intersection.  -1 for non-intersection patches.
  auto?           ;; whether or not this intersection will switch automatically.
                  ;; false for non-intersection patches.
]


;;;;;;;;;;;;;;;;;;;;;;
;; Setup Procedures ;;
;;;;;;;;;;;;;;;;;;;;;;

;; Initialize the display by giving the global and patch variables initial values.
;; Create num-cars of turtles if there are enough road patches for one turtle to
;; be created per road patch. Set up the plots.
to setup
  clear-all
  setup-globals

  if custom-map [
    import-pcolors "silnice-3.png"
  ]

  setup-patches
  set-default-shape turtles "car"

  set emission-rate 112  ;; grams of CO2 per kilometer
  set emission-rate-idle 0.4032  ;; grams of CO2 per second


  ;; Now create the turtles and have each created turtle call the functions setup-cars
  create-turtles num-cars [
      setup-cars
      ;;record-data
    ]

  ;; give the turtles an initial speed
  ask turtles [ set-car-speed ]

  reset-ticks
end

;; Initialize the global variables to appropriate values
to setup-globals
  set phase 0
  set num-cars-stopped 0
  set grid-x-inc world-width / grid-size-x
  set grid-y-inc world-height / grid-size-y
  set total-lifetime 0

  set acceleration 0.099
end
;; Make the patches have appropriate colors, set up the roads and intersections agentsets,
;; and initialize the traffic lights to one setting
to setup-patches

  ifelse custom-map
  [
    ask patches
    [
      set intersection? false
      set auto? false
      set green-light-up? true
      set my-row -1
      set my-column -1
      set my-phase -1
    ]
    ;; Initialize the global variables that hold patch agentsets
    set roads patches with [pcolor = black]
    let intersection-locations [[-5 4] [-2 4] [-2 2] [5 4] [-5 2] [5 2]]

    ;; Initialize intersections based on specified locations
    set intersections patches with [
      member? (list pxcor pycor) intersection-locations
    ]
  ] [
    ask patches
    [
      set intersection? false
      set auto? false
      set green-light-up? true
      set my-row -1
      set my-column -1
      set my-phase -1
      set pcolor green - 2
    ]
    ;; initialize the global variables that hold patch agentsets
    set roads patches with
    [(floor((pxcor + max-pxcor - floor(grid-x-inc - 1)) mod grid-x-inc) = 0) or
      (floor((pycor + max-pycor) mod grid-y-inc) = 0)]
    set intersections roads with
    [(floor((pxcor + max-pxcor - floor(grid-x-inc - 1)) mod grid-x-inc) = 0) and
      (floor((pycor + max-pycor) mod grid-y-inc) = 0)]

    ask roads [ set pcolor black + 5 ]
  ]

  setup-intersections
end

;; Give the intersections appropriate values for the intersection?, my-row, and my-column
;; patch variables.  Make all the traffic lights start off so that the lights are red
;; horizontally and green vertically.
to setup-intersections
  ask intersections
  [
    set intersection? true
    set green-light-up? true
    set my-phase 0
    set auto? true
    set my-row floor((pycor + max-pycor) / grid-y-inc)
    set my-column floor((pxcor + max-pxcor) / grid-x-inc)
    set-signal-colors
  ]
end

;; Initialize the turtle variables to appropriate values and place the turtle on an empty road patch.
to setup-cars  ;; turtle procedure
  set speed 0
  set wait-time 0
  set lifetime 0  ;; Initialize lifetime to a value, adjust as needed
  put-on-empty-road

  ifelse custom-map [
    ifelse intersection?
    [
      ifelse random 2 = 0
      [ set up-car? true ]
      [ set up-car? false ]
    ]
    [
      ;; Check the color of the patch to the left
      let left-patch patch-at -1 0
      ifelse ([pcolor] of left-patch = black)
      [ set up-car? false ]
      [ set up-car? true ]
    ]
  ] [
    ifelse intersection?
    [
      ifelse random 2 = 0
      [ set up-car? true ]
      [ set up-car? false ]
    ]
    [

      ; if the turtle is on a vertical road (rather than a horizontal one)
      ifelse (floor((pxcor + max-pxcor + floor(grid-x-inc - 1)) mod grid-x-inc) = 0)
      [ set up-car? true ]
      [ set up-car? false ]
    ]
  ]
  ifelse up-car?
  [ set heading 180 ]
  [ set heading 90 ]
end

;; Find a road patch without any turtles on it and place the turtle there.
to put-on-empty-road  ;; turtle procedure
  move-to one-of roads with [not any? turtles-on self]
end




;;;;;;;;;;;;;;;;;;;;;;;;
;; Runtime Procedures ;;
;;;;;;;;;;;;;;;;;;;;;;;;

;; Run the simulation
to go

  ;; have the intersections change their color
  set-signals
  set num-cars-stopped 0

  ;; set the turtles speed for this time thru the procedure, move them forward their speed,
  ;; record data for plotting, and set the color of the turtles to an appropriate color
  ;; based on their speed

  ask turtles [
    set-car-speed
    fd speed
    record-data

    ;; Check if the turtle has reached the opposite destination and kill it
    check-turtle-status
  ]

  ;; Check if the percentage of stopped cars exceeds 80%, and if so, call reset pseed
  let percentage-stopped num-cars-stopped / count turtles
  if percentage-stopped >= 0.8 [
    reset-speed
  ]

  ;; Check if the number of turtles is less than a threshold, and if so, create a new turtle
  if count turtles < num-cars [
    repeat (num-cars - count turtles) [
      create-new-car
    ]
  ]

  ;; update the phase and the global clock
  next-phase
  tick
end

to create-new-car
  create-turtles 1 [
    setup-cars
  ]
end

to reset-speed
  ask turtles [
    set speed 0.1
  ]
end

;; Check if the turtle has reached the opposite destination or is off the grid, and kill it if true
to check-turtle-status
  if destination-reached? or off-grid? [
    set total-lifetime total-lifetime + lifetime
    set total-killed-cars total-killed-cars + 1
    set total-emissions total-emissions + emissions
    set total-emissions-idle total-emissions-idle + emissions-idle
    die  ;; Kill the turtle if it reaches the opposite destination or is off the grid
  ]
end

to-report destination-reached?
  ;; Report true if the turtle has reached the opposite destination
  report (up-car? and xcor >= max-pxcor) or (not up-car? and ycor >= max-pycor)
end

to-report off-grid?
  ;; Report true if the turtle is off the grid
  report xcor <= min-pxcor or xcor >= max-pxcor or ycor <= min-pycor or ycor >= max-pycor
end


;; have the traffic lights change color if phase equals each intersections' my-phase
to set-signals
  ask intersections with [auto? and phase = floor ((my-phase * ticks-per-cycle) / 100)]
  [
    set green-light-up? (not green-light-up?)
    set-signal-colors
  ]
end

;; This procedure checks the variable green-light-up? at each intersection and sets the
;; traffic lights to have the green light up or the green light to the left.
to set-signal-colors  ;; intersection (patch) procedure
  ifelse power?
  [
    ifelse green-light-up?
    [
      ask patch-at -1 0 [ set pcolor red ]
      ask patch-at 0 1 [ set pcolor green ]
    ]
    [
      ask patch-at -1 0 [ set pcolor green ]
      ask patch-at 0 1 [ set pcolor red ]
    ]
  ]
  [
    ask patch-at -1 0 [ set pcolor white ]
    ask patch-at 0 1 [ set pcolor white ]
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;
;; Speed regulation   ;;
;;;;;;;;;;;;;;;;;;;;;;;;
;; set the turtles' speed based on whether they are at a red traffic light or the speed of the
;; turtle (if any) on the patch in front of them
to set-car-speed  ;; turtle procedure
  ifelse pcolor = red
  [ set speed 0 ]
  [
    ifelse up-car?
    [ set-speed 0 -1 ]
    [ set-speed 1 0 ]
  ]
end

;; set the speed variable of the car to an appropriate value (not exceeding the
;; speed limit) based on whether there are cars on the patch in front of the car
to set-speed [ delta-x delta-y ]  ;; turtle procedure
  ;; get the turtles on the patch in front of the turtle
  let turtles-ahead turtles-at delta-x delta-y

  ;; if there are turtles in front of the turtle, slow down
  ;; otherwise, speed up
  ifelse any? turtles-ahead
  [
    ifelse any? (turtles-ahead with [ up-car? != [up-car?] of myself ])
    [
      set speed 0
    ][
      set speed [speed] of one-of turtles-ahead
      slow-down
    ]
  ]
  [ speed-up ]
end

;; decrease the speed of the turtle
to slow-down  ;; turtle procedure
  ifelse speed <= 0  ;;if speed < 0
  [ set speed 0 ]
  [ set speed speed - acceleration ]
  set actual-speed ((200 / 9) * (speed - 0.1)) + 30
end

;; increase the speed of the turtle
to speed-up  ;; turtle procedure
  let speed-limit-adjusted 0.1 + ((speed-limit - 30) * 9 / 200)
  ifelse speed > speed-limit-adjusted
  [ set speed speed-limit-adjusted ]
  [ set speed speed + acceleration ]
  set actual-speed ((200 / 9) * (speed - 0.1)) + 30
end


;;;;;;;;;;;;;;;;;;;;;;;;
;; Turtles data recording ;;
;;;;;;;;;;;;;;;;;;;;;;;;

;; keep track of the number of stopped turtles and the amount of time a turtle has been stopped
;; if its speed is 0
to record-data  ;; turtle procedure
  let distance-per-tick speed  ;; Assuming speed is in meters per tick, convert to kilometers
  set distance-traveled distance-traveled + distance-per-tick
  set emissions distance-traveled * emission-rate  ;; emissions in grams

  set lifetime lifetime + 1  ;; Increase lifetime for each turtle
  ifelse speed = 0
  [
    set num-cars-stopped num-cars-stopped + 1
    set wait-time wait-time + 1
    if wait-time > 100 [set speed 0.1]
    set emissions-idle emissions-idle + emission-rate-idle  ;; emissions in kilograms
  ]
  [ set wait-time 0 ]
  if total-killed-cars > 0 [set avg-lifetime (total-lifetime / total-killed-cars)]
end


;; cycles phase to the next appropriate value
to next-phase
  ;; The phase cycles from 0 to ticks-per-cycle, then starts over.
  set phase phase + 1
  if phase mod ticks-per-cycle = 0
    [ set phase 0 ]
end
@#$#@#$#@
GRAPHICS-WINDOW
12
10
580
579
-1
-1
22.4
1
12
1
1
1
0
1
1
1
-12
12
-12
12
1
1
1
ticks
30.0

PLOT
1275
183
1493
347
Average Wait Time of Cars
Time
Average Wait
0.0
100.0
0.0
5.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [wait-time] of turtles"

PLOT
1059
15
1275
180
Average Speed of Cars
Time
Average Speed
0.0
100.0
0.0
50.0
true
false
"set-plot-y-range 0 speed-limit" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [actual-speed] of turtles"

SLIDER
583
506
680
539
grid-size-y
grid-size-y
1
9
5.0
1
1
NIL
HORIZONTAL

SLIDER
583
541
677
574
grid-size-x
grid-size-x
1
9
5.0
1
1
NIL
HORIZONTAL

SWITCH
581
473
676
506
power?
power?
0
1
-1000

SLIDER
584
50
865
83
num-cars
num-cars
1
400
34.0
1
1
NIL
HORIZONTAL

PLOT
1280
15
1494
179
Stopped Cars
Time
Stopped Cars
0.0
100.0
0.0
100.0
true
false
"set-plot-y-range 0 num-cars" ""
PENS
"default" 1.0 0 -16777216 true "" "plot num-cars-stopped"

BUTTON
835
13
899
46
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
743
13
827
46
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
584
13
738
46
speed-limit
speed-limit
30
50
30.0
1
1
NIL
HORIZONTAL

SLIDER
581
437
735
470
ticks-per-cycle
ticks-per-cycle
1
100
25.0
1
1
NIL
HORIZONTAL

MONITOR
593
378
650
423
# Cars
count turtles
17
1
11

MONITOR
655
379
748
424
NIL
total-lifetime
17
1
11

MONITOR
594
330
707
375
NIL
total-killed-cars
17
1
11

MONITOR
753
379
840
424
NIL
avg-lifetime
17
1
11

BUTTON
583
92
688
125
Reset speed
reset-speed
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1281
388
1499
551
Avg Emissions Driving
Time
Emissions
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -11881837 true "" "plot mean [emissions] of turtles"

PLOT
1059
389
1271
550
Avg Emissions on Idle
Time
Emissions
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -14454117 true "" "plot mean [emissions-idle] of turtles"

SWITCH
706
93
842
126
custom-map
custom-map
0
1
-1000

@#$#@#$#@
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
true
0
Polygon -7500403 true true 180 15 164 21 144 39 135 60 132 74 106 87 84 97 63 115 50 141 50 165 60 225 150 285 165 285 225 285 225 15 180 15
Circle -16777216 true false 180 30 90
Circle -16777216 true false 180 180 90
Polygon -16777216 true false 80 138 78 168 135 166 135 91 105 106 96 111 89 120
Circle -7500403 true true 195 195 58
Circle -7500403 true true 195 47 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.4.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>total-killed-cars = 300000</exitCondition>
    <metric>sum [emissions] of turtles</metric>
    <metric>sum [emissions-idle] of turtles</metric>
  </experiment>
  <experiment name="experiment-50" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>total-killed-cars = 300000</exitCondition>
    <metric>sum [emissions] of turtles</metric>
    <metric>sum [emissions-idle] of turtles</metric>
  </experiment>
  <experiment name="experiment (copy)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>total-killed-cars = 300000</exitCondition>
    <metric>total-emissions-idle</metric>
    <metric>total-emissions</metric>
  </experiment>
  <experiment name="experiment (copy) 30" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>total-killed-cars = 300000</exitCondition>
    <metric>total-emissions-idle</metric>
    <metric>total-emissions</metric>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
